@@ -5,42 +5,19 @@ from django.utils.safestring import mark_safe
 from django.utils.encoding import force_text
 from django.forms.util import flatatt
 from django.forms import widgets
-from djangular.forms.widgets import CheckboxSelectMultiple as DjngCheckboxSelectMultiple
+from djangular.forms.widgets import (
+    ChoiceFieldRenderer as DjngChoiceFieldRenderer, CheckboxChoiceInput as DjngCheckboxChoiceInput,
+    CheckboxFieldRendererMixin, CheckboxSelectMultiple as DjngCheckboxSelectMultiple,
+    RadioFieldRendererMixin, RadioSelect as DjngRadioSelect)
 
 
-class CheckboxChoiceInput(widgets.CheckboxChoiceInput):
-    def render(self, name=None, value=None, attrs=None, choices=()):
-        name = name or self.name
-        value = value or self.value
-        attrs = attrs or self.attrs
-        label_attrs = ['class="checkbox-inline"']
-        if 'id' in self.attrs:
-            label_attrs.append(format_html('for="{0}_{1}"', self.attrs['id'], self.index))
-        label_for = mark_safe(' '.join(label_attrs))
-        return format_html('<label {0}>{1} {2}</label>', label_for, self.tag(), self.choice_label)
-
-    def tag(self):
-        if 'id' in self.attrs:
-            self.attrs['id'] = '%s_%s' % (self.attrs['id'], self.index)
-        if 'ng-model' in self.attrs:
-            self.attrs['ng-model'] = '%s.%s' % (self.attrs['ng-model'], self.choice_value)
-        name = '%s.%s' % (self.name, self.choice_value)
-        final_attrs = dict(self.attrs, type=self.input_type, name=name, value=self.choice_value)
-        if self.is_checked():
-            final_attrs['checked'] = 'checked'
-        return format_html('<input{0} />', flatatt(final_attrs))
-
-
-class CheckboxFieldRenderer(widgets.ChoiceFieldRenderer):
-    choice_input_class = CheckboxChoiceInput
-
+class ChoiceFieldRenderer(DjngChoiceFieldRenderer):
     def render(self):
         """
-        Outputs a <ul> for this set of choice fields.
-        If an id was given to the field, it is applied to the <ul> (each
-        item in the list will get an id of `$id_$i`).
+        Outputs a <div ng-form="name"> for this set of choice fields to nest an ngForm.
         """
-        output = ['<div>']
+        start_tag = format_html('<div {0}>', mark_safe(' '.join(self.field_attrs)))
+        output = [start_tag]
         for widget in self:
             output.append(force_text(widget))
         output.append('</div>')
@@ -58,6 +35,26 @@ class CheckboxInput(widgets.CheckboxInput):
         return format_html('<label {0}>{1} {2}</label>', label_for, tag, self.choice_label)
 
 
+class CheckboxChoiceInput(DjngCheckboxChoiceInput):
+    def render(self, name=None, value=None, attrs=None, choices=()):
+        name = name or self.name
+        value = value or self.value
+        attrs = attrs or self.attrs
+        label_attrs = ['class="checkbox-inline"']
+        if 'id' in self.attrs:
+            label_attrs.append(format_html('for="{0}_{1}"', self.attrs['id'], self.index))
+        label_for = mark_safe(' '.join(label_attrs))
+        return format_html('<label {0}>{1} {2}</label>', label_for, self.tag(), self.choice_label)
+
+
+class CheckboxFieldRenderer(CheckboxFieldRendererMixin, ChoiceFieldRenderer):
+    choice_input_class = CheckboxChoiceInput
+
+
+class CheckboxSelectMultiple(DjngCheckboxSelectMultiple):
+    renderer = CheckboxFieldRenderer
+
+
 class RadioChoiceInput(widgets.RadioChoiceInput):
     def render(self, name=None, value=None, attrs=None, choices=()):
         name = name or self.name
@@ -65,30 +62,22 @@ class RadioChoiceInput(widgets.RadioChoiceInput):
         attrs = attrs or self.attrs
         label_attrs = ['class="radio-inline"']
         if 'id' in self.attrs:
-            label_attrs.append(format_html(' for="{0}_{1}"', self.attrs['id'], self.index))
+            label_attrs.append(format_html('for="{0}_{1}"', self.attrs['id'], self.index))
         label_for = mark_safe(' '.join(label_attrs))
         return format_html('<label {0}>{1} {2}</label>', label_for, self.tag(), self.choice_label)
 
+    def tag(self):
+        tag_attrs = dict(self.attrs, type=self.input_type, name=self.name, value=self.choice_value)
+        if 'id' in self.attrs:
+            tag_attrs['id'] = '{0}_{1}'.format(tag_attrs['id'], self.index)
+        if self.is_checked():
+            tag_attrs['checked'] = 'checked'
+        return format_html('<input{0} />', flatatt(tag_attrs))
 
-class RadioFieldRenderer(widgets.RadioFieldRenderer):
+
+class RadioFieldRenderer(RadioFieldRendererMixin, ChoiceFieldRenderer):
     choice_input_class = RadioChoiceInput
 
-    def render(self):
-        """
-        Outputs a <ul> for this set of choice fields.
-        If an id was given to the field, it is applied to the <ul> (each
-        item in the list will get an id of `$id_$i`).
-        """
-        output = ['<div>']
-        for widget in self:
-            output.append(force_text(widget))
-        output.append('</div>')
-        return mark_safe('\n'.join(output))
 
-
-class RadioSelect(widgets.RadioSelect):
+class RadioSelect(DjngRadioSelect):
     renderer = RadioFieldRenderer
-
-
-class CheckboxSelectMultiple(DjngCheckboxSelectMultiple):
-    renderer = CheckboxFieldRenderer
